.. :changelog:

History
-------

0.2.0 (2019-07-23)
++++++++++++++++++

* Change behaviour of --expected-num-workers to only report to admins when the number of workers are less than the expected value. Add test versions for Python 3.6 and Django 2.2.

0.1.4 (2018-02-13)
++++++++++++++++++

* Use the built in mail_admins Django function instead of send_mail.

0.1.3 (2018-02-12)
++++++++++++++++++

* Add commands to Makefile to simplify the package build and release process.

0.1.2 (2018-02-12)
++++++++++++++++++

* Modify setup.py to enable the usage of bumpversion.

0.1.1 (2018-02-12)
++++++++++++++++++

* Allow the Redis connection details to be customizable.

0.1.0 (2018-01-19)
++++++++++++++++++

* First release on PyPI.
